summaryrefslogtreecommitdiff
path: root/framework/Data/ActiveRecord/TActiveRecord.php
diff options
context:
space:
mode:
Diffstat (limited to 'framework/Data/ActiveRecord/TActiveRecord.php')
-rw-r--r--framework/Data/ActiveRecord/TActiveRecord.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/framework/Data/ActiveRecord/TActiveRecord.php b/framework/Data/ActiveRecord/TActiveRecord.php
index 2bdba2d1..ba1bcc29 100644
--- a/framework/Data/ActiveRecord/TActiveRecord.php
+++ b/framework/Data/ActiveRecord/TActiveRecord.php
@@ -187,9 +187,9 @@ abstract class TActiveRecord extends TComponent
}
/**
* Prevent __call() method creating __wake() when unserializing.
*/
- public function __wake()
+ public function __wakeup()
{
$this->setupColumnMapping();
$this->setupRelations();
@@ -187,9 +187,9 @@ abstract class TActiveRecord extends TComponent
}
/**
- * Prevent __call() method creating __wake() when unserializing.
+ * Prevent __call() method creating __wakeup() when unserializing.
*/